CVXR-package: CVXR: Disciplined Convex Optimization

CVXR-packageR Documentation

CVXR: Disciplined Convex Optimization

Description

logo

An object-oriented modeling language for disciplined convex programming (DCP) as described in Fu, Narasimhan, and Boyd (2020, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.18637/jss.v094.i14")}). It allows the user to formulate convex optimization problems in a natural way following mathematical convention and DCP rules. The system analyzes the problem, verifies its convexity, converts it into a canonical form, and hands it off to an appropriate solver to obtain the solution. This version uses the S7 object system for improved performance and maintainability.

Author(s)

Maintainer: Anqi Fu anqif@alumni.stanford.edu

Authors:

Other contributors:

See Also

Useful links:


CVXR documentation built on March 6, 2026, 9:10 a.m.