| FiniteSet | R Documentation |
Constrain each entry of an Expression to take a value in a given finite set of real numbers.
FiniteSet(expre, vec, ineq_form = FALSE, constr_id = NULL)
expre |
An affine Expression. |
vec |
A numeric vector (or set) of allowed values. |
ineq_form |
Logical; controls MIP canonicalization strategy.
If |
constr_id |
Optional integer constraint ID (internal use). |
A FiniteSet constraint.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.