Learn R Programming

CVXR (version 1.9.1)

PartialProblem: Partial optimization of a Problem

Description

A PartialProblem is an Expression that represents the optimal value of an inner Problem as a function of the variables you choose NOT to optimise over. Build one with partial_optimize() rather than constructing the class directly.

Usage

PartialProblem(
  prob,
  opt_vars,
  dont_opt_vars,
  solver = NULL,
  solve_kwargs = list(),
  id = NULL
)

Arguments