View source: R/054_atoms_affine_diff.R
| cvxr_diff | R Documentation |
Takes in an expression and returns an expression with the kth order differences along the given axis. The output shape is the same as the input except the size along the specified axis is reduced by k.
cvxr_diff(x, k = 1L, axis = 2L)
x |
An Expression or numeric value. |
k |
Integer. The number of times values are differenced. Default is 1.
(Mapped from R's |
axis |
Integer. The axis along which the difference is taken. 2 = along rows/down columns (default), 1 = along columns/across rows. |
An Expression representing the kth order differences.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.