intf_shape: Get the shape of a value as an integer vector c(nrow, ncol)

View source: R/019_interface_matrix_utilities.R

intf_shapeR Documentation

Get the shape of a value as an integer vector c(nrow, ncol)

Description

Get the shape of a value as an integer vector c(nrow, ncol)

Usage

intf_shape(val)

Arguments

val

A numeric scalar, vector, matrix, or Matrix object

Value

Integer vector of length 2


CVXR documentation built on March 6, 2026, 9:10 a.m.