| is_dpp | R Documentation |
Determines whether an expression or problem satisfies the rules of Disciplined Parameterized Programming (DPP). A DPP-compliant problem enables caching the compilation across parameter value changes.
is_dpp(x, context = "dcp")
x |
An expression, constraint, or problem object. |
context |
Either |
Logical scalar.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.