mul_sign: Sign of a product of two expressions

View source: R/006_utilities_sign.R

mul_signR Documentation

Sign of a product of two expressions

Description

Determines whether the product of two expressions is nonnegative, nonpositive, or unknown, using the sign multiplication table.

Usage

mul_sign(lh_expr, rh_expr)

Arguments

lh_expr

An Expression object (left-hand operand)

rh_expr

An Expression object (right-hand operand)

Value

Named logical vector c(is_nonneg, is_nonpos)


CVXR documentation built on March 6, 2026, 9:10 a.m.