param_dict: Get all Parameters of a Problem as a Named List

param_dictR Documentation

Get all Parameters of a Problem as a Named List

Description

Mirrors CVXPY's Problem.param_dict property (cvxpy/problems/problem.py:260-264): returns a named list keyed by each parameter's name, where the value is the Parameter object itself.

Usage

param_dict(x, ...)

Arguments

x

A Problem object.

...

Not used.

Value

Named list of Parameter objects, keyed by name.


CVXR documentation built on Aug. 24, 2026, 9:10 a.m.