partial_transpose: Partial transpose of a tensor product expression

View source: R/047_atoms_affine_partial_transpose.R

partial_transposeR Documentation

Partial transpose of a tensor product expression

Description

Assumes expr is a 2D square matrix representing a Kronecker product of length(dims) subsystems. Returns the partial transpose with the transpose applied to the subsystem at index axis (1-indexed).

Usage

partial_transpose(expr, dims, axis = 1L)

Arguments

expr

An Expression (2D square matrix)

dims

Integer vector of subsystem dimensions

axis

Integer (1-indexed) subsystem to transpose

Value

An Expression representing the partial transpose


CVXR documentation built on March 6, 2026, 9:10 a.m.