project: Project a Value onto the Domain of a Leaf

projectR Documentation

Project a Value onto the Domain of a Leaf

Description

Project a Value onto the Domain of a Leaf

Usage

project(x, val, ...)

Arguments

x

A leaf expression object.

val

The value to project.

...

Additional arguments.

Value

The projected value.


CVXR documentation built on April 4, 2026, 9:08 a.m.