solution: Get the Raw Solution Object

View source: R/132_problems_problem.R

solutionR Documentation

Get the Raw Solution Object

Description

Returns the raw Solution object from the most recent solve, containing primal and dual variable values, status, and solver attributes.

Usage

solution(x)

Arguments

x

A Problem object.

Value

A Solution object, or NULL if the problem has not been solved.


CVXR documentation built on March 6, 2026, 9:10 a.m.