| supports_quad_obj | R Documentation |
CVXPY v1.8.2: controls whether the conic path keeps the quadratic objective as a P matrix or decomposes it into cones.
supports_quad_obj(x, ...)
x |
A solver object. |
Logical scalar.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.