var_dict: Get all Variables of a Problem as a Named List

var_dictR Documentation

Get all Variables of a Problem as a Named List

Description

Mirrors CVXPY's Problem.var_dict property (cvxpy/problems/problem.py:267-271): returns a named list keyed by each variable's name, where the value is the Variable object itself.

Usage

var_dict(x, ...)

Arguments

x

A Problem object.

...

Not used.

Value

Named list of Variable objects, keyed by name.


CVXR documentation built on Aug. 24, 2026, 9:10 a.m.