| CVXR-package | R Documentation |
An object-oriented modeling language for disciplined convex programming (DCP) as described in Fu, Narasimhan, and Boyd (2020, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.18637/jss.v094.i14")}). It allows the user to formulate convex optimization problems in a natural way following mathematical convention and DCP rules. The system analyzes the problem, verifies its convexity, converts it into a canonical form, and hands it off to an appropriate solver to obtain the solution. This version uses the S7 object system for improved performance and maintainability.
Maintainer: Anqi Fu anqif@alumni.stanford.edu
Authors:
Balasubramanian Narasimhan naras@stat.stanford.edu
Steven Diamond
John Miller
Other contributors:
Stephen Boyd boyd@stanford.edu [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.