| Or | R Documentation |
Returns 1 if and only if at least one argument equals 1, and 0 otherwise.
For two operands, can also be written with the | operator: x | y.
Or(..., id = NULL)
... |
Two or more boolean Variables or logic expressions. |
id |
Optional integer ID (internal use). |
An Or expression.
Not(), And(), Xor(), implies(), iff()
## Not run:
x <- Variable(boolean = TRUE)
y <- Variable(boolean = TRUE)
either <- x | y # operator syntax
either <- Or(x, y) # functional syntax
any3 <- Or(x, y, z) # n-ary
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.