Learn R Programming

CVXR (version 1.9.1)

Or: Logical OR

Description

Returns 1 if and only if at least one argument equals 1, and 0 otherwise. For two operands, can also be written with the | operator: x | y.

Usage

Or(..., id = NULL)

Value

An Or expression.

Arguments

...

Two or more boolean Variables or logic expressions.

id

Optional integer ID (internal use).

See Also

Not(), And(), Xor(), implies(), iff()

Examples

Run this code
if (FALSE) {
x <- Variable(boolean = TRUE)
y <- Variable(boolean = TRUE)
either <- x | y          # operator syntax
either <- Or(x, y)       # functional syntax
any3 <- Or(x, y, z)      # n-ary
}

Run the code above in your browser using DataLab