powered by
Returns 1 if and only if at least one argument equals 1, and 0 otherwise. For two operands, can also be written with the | operator: x | y.
|
x | y
Or(..., id = NULL)
An Or expression.
Or
Two or more boolean Variables or logic expressions.
Optional integer ID (internal use).
Not(), And(), Xor(), implies(), iff()
Not()
And()
Xor()
implies()
iff()
if (FALSE) { x <- Variable(boolean = TRUE) y <- Variable(boolean = TRUE) either <- x | y # operator syntax either <- Or(x, y) # functional syntax any3 <- Or(x, y, z) # n-ary }
Run the code above in your browser using DataLab