| Parameter | R Documentation |
Constructs a parameter whose numeric value can be changed without re-canonicalizing the problem. Parameters are treated as constants for DCP purposes but their value can be updated between solves.
Parameter(
shape = c(1L, 1L),
name = NULL,
value = NULL,
id = NULL,
latex_name = NULL,
...
)
shape |
Integer vector of length 1 or 2 giving the parameter
dimensions. A scalar |
name |
Optional character string name. If |
value |
Optional initial numeric value. |
id |
Optional integer ID. |
latex_name |
Optional character string giving a custom LaTeX name for
use in visualizations. For example, |
... |
Additional attributes: |
A Parameter object (inherits from Leaf and
Expression).
p <- Parameter()
value(p) <- 5
p_vec <- Parameter(3, nonneg = TRUE)
gamma <- Parameter(1, name = "gamma", latex_name = "\\gamma")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.