Learn R Programming

CVXR (version 1.9.1)

backward: Compute the gradient of a solution with respect to Parameters

Description

Differentiates through the solution map of problem: populates the gradient slot of each Parameter with the sensitivity of a scalar-valued function of the variables (defaulting to the sum-of-x loss; override per variable by setting gradient(variable) <- before calling) with respect to that parameter. Mirrors cvxpy.Problem.backward().

Usage

backward(problem)

Value

The problem (for piping); side-effect sets gradient(param) on each parameter.

Arguments

problem

A solved Problem.

Details

Must be called after psolve() with requires_grad = TRUE.

See Also

derivative(), psolve(), gradient()