View source: R/304_zzz_R_specific_grad_delta_attrs.R
| gradient | R Documentation |
Used by psolve() with requires_grad = TRUE and
Problem$backward(). Stores a numeric array of the same shape as
the leaf, or NULL (the default).
gradient(x)
gradient(x) <- value
x |
A |
value |
A numeric array of the same shape as |
The gradient (numeric array) or NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.