View source: R/019_interface_matrix_utilities.R
| intf_shape | R Documentation |
Get the shape of a value as an integer vector c(nrow, ncol)
intf_shape(val)
val |
A numeric scalar, vector, matrix, or Matrix object |
Integer vector of length 2
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.