Learn R Programming

CVXR (version 1.9.1)

intf_shape: Get the shape of a value as an integer vector c(nrow, ncol)

Description

Get the shape of a value as an integer vector c(nrow, ncol)

Usage

intf_shape(val)

Value

Integer vector of length 2

Arguments

val

A numeric scalar, vector, matrix, or Matrix object