Learn R Programming

CVXR (version 1.9.1)

is_dpp: Check DPP Compliance

Description

Determines whether an expression or problem satisfies the rules of Disciplined Parameterized Programming (DPP). A DPP-compliant problem enables caching the compilation across parameter value changes.

Usage

is_dpp(x, context = "dcp")

Value

Logical scalar.

Arguments

x

An expression, constraint, or problem object.

context

Either "dcp" (default) or "dgp": which discipline to check parameterization against. Mirrors CVXPY's is_dpp(context=...).