View source: R/116_atoms_length.R
| length_expr | R Documentation |
Returns the index of the last nonzero element of a vector (1-based).
This atom is quasiconvex but NOT convex, so it can only be used in
DQCP problems (solved with qcp = TRUE).
length_expr(x)
x |
A CVXR vector expression. |
A Length expression (scalar).
ceil_expr, floor_expr
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.