View source: R/006_utilities_sign.R
| mul_sign | R Documentation |
Determines whether the product of two expressions is nonnegative, nonpositive, or unknown, using the sign multiplication table.
mul_sign(lh_expr, rh_expr)
lh_expr |
An Expression object (left-hand operand) |
rh_expr |
An Expression object (right-hand operand) |
Named logical vector c(is_nonneg, is_nonpos)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.