Learn R Programming

CVXR (version 1.9.1)

mul_sign: Sign of a product of two expressions

Description

Determines whether the product of two expressions is nonnegative, nonpositive, or unknown, using the sign multiplication table.

Usage

mul_sign(lh_expr, rh_expr)

Value

Named logical vector c(is_nonneg, is_nonpos)

Arguments

lh_expr

An Expression object (left-hand operand)

rh_expr

An Expression object (right-hand operand)