Learn R Programming

CVXR (version 1.9.1)

param_dict: Get all Parameters of a Problem as a Named List

Description

Mirrors CVXPY's Problem.param_dict property (cvxpy/problems/problem.py:260-264): returns a named list keyed by each parameter's name, where the value is the Parameter object itself.

Usage

param_dict(x, ...)

Value

Named list of Parameter objects, keyed by name.

Arguments

x

A Problem object.

...

Not used.