Learn R Programming

CVXR (version 1.9.1)

partial_trace: Partial trace of a tensor product expression

Description

Assumes expr is a 2D square matrix representing a Kronecker product of length(dims) subsystems. Returns the partial trace over the subsystem at index axis (1-indexed).

Usage

partial_trace(expr, dims, axis = 1L)

Value

An Expression representing the partial trace

Arguments

expr

An Expression (2D square matrix)

dims

Integer vector of subsystem dimensions

axis

Integer (1-indexed) subsystem to trace out