| problem_data | R Documentation |
Returns the problem data that would be passed to a specific solver, along with the reduction chain and inverse data for solution retrieval.
problem_data(x, solver = NULL, ...)
x |
A |
solver |
Character string naming solver, or |
... |
Additional arguments. |
A list with components data, chain, and
inverse_data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.