View source: R/132_problems_problem.R
| problem_unpack_results | R Documentation |
Inverts the reduction chain and unpacks the raw solver solution into the original problem's variables and constraints. This is step 3 of the decomposed solve pipeline:
problem_data() – compile the problem
solve_via_data(chain, data) – call the solver
problem_unpack_results() – invert and unpack
problem_unpack_results(problem, solution, chain, inverse_data)
problem |
A |
solution |
The raw solver result from |
chain |
The |
inverse_data |
The inverse data list from |
After calling this function, variable values are available via
value() and constraint duals via dual_value().
The problem object (invisibly), with solution unpacked.
problem_data, solve_via_data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.