Learn R Programming

CVXR (version 1.9.1)

project: Project a Value onto the Domain of a Leaf

Description

Project a Value onto the Domain of a Leaf

Usage

project(x, val, ...)

Value

The projected value.

Arguments

x

A leaf expression object.

val

The value to project.

...

Additional arguments.