View source: R/132_problems_problem.R
| solution | R Documentation |
Returns the raw Solution object from the most recent solve,
containing primal and dual variable values, status, and solver
attributes.
solution(x)
x |
A |
A Solution object, or NULL if the problem
has not been solved.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.