Learn R Programming

CVXR (version 1.9.1)

solution: Get the Raw Solution Object

Description

Returns the raw Solution object from the most recent solve, containing primal and dual variable values, status, and solver attributes.

Usage

solution(x)

Value

A Solution object, or NULL if the problem has not been solved.

Arguments

x

A Problem object.