powered by
Returns the raw Solution object from the most recent solve, containing primal and dual variable values, status, and solver attributes.
Solution
solution(x)
A Solution object, or NULL if the problem has not been solved.
NULL
A Problem object.
Problem