Learn R Programming

CVXR (version 1.9.1)

var_dict: Get all Variables of a Problem as a Named List

Description

Mirrors CVXPY's Problem.var_dict property (cvxpy/problems/problem.py:267-271): returns a named list keyed by each variable's name, where the value is the Variable object itself.

Usage

var_dict(x, ...)

Value

Named list of Variable objects, keyed by name.

Arguments

x

A Problem object.

...

Not used.